extends CanvasLayer

var SFXVol
var musicVol
var voiceVol
var screenScale
var screenScaleMax

var isPaused = false
@onready var parallaxBackground = $"ParallaxBackground"
@onready var pausePlayer = $"Paused-Player"

#	Config UI bars
@onready var config_Music_Bar = $"CanvasLayer/Config-Btns-Control/Music/Music-Bar-Group/Music-Bar"
@onready var config_SFX_Bar = $"CanvasLayer/Config-Btns-Control/SFX/SFX-Bar-Group/SFX-Bar"
@onready var config_Voice_Bar = $"CanvasLayer/Config-Btns-Control/Voice/Voice-Bar-Group/Voice-Bar"

@onready var titleScenePath = "res://Triple-Tyrant/TripTy-Scenes/TripTy-Title-Scene.tscn"

var clickedCredits = false

func _ready():
	
	screenScale = int(DisplayServer.window_get_size().y/ 120)
	screenScaleMax = int(DisplayServer.screen_get_size().y/ 120)
	musicVol = clamp(AudioServer.get_bus_volume_db(AudioServer.get_bus_index("Music")) + 10,0,10)
	SFXVol = clamp(AudioServer.get_bus_volume_db(AudioServer.get_bus_index("SFX")) + 10,0,10)
	voiceVol = clamp(AudioServer.get_bus_volume_db(AudioServer.get_bus_index("Voice")) + 10,0,10)
	checkVolBars()
	updateScreenTextAndSize(0)

func _process(delta):
	if(Input.is_action_just_pressed("pause")):
		togglePauseMenu()

func togglePauseMenu():
	isPaused = !isPaused
	changePaused(isPaused)

func changePaused(val):
	#visible = val
	#parallaxBackground.visible = val
	if(clickedCredits):
		if(val):
			pausePlayer.play("Credits-Show")
		else:
			pausePlayer.play("Credits-Hide")
			clickedCredits = false
	else:
		if(val):
			pausePlayer.play("Pause-Show")
		else:
			pausePlayer.play("Pause-Hide")
	get_tree().paused = val
	isPaused = val
	
func changeButtonsActive(bol):
	pass
	
func checkVolBars():
	config_Music_Bar.value = musicVol
	config_SFX_Bar.value = SFXVol
	config_Voice_Bar.value = voiceVol

func updateScreenTextAndSize(val):
	if(DisplayServer.window_get_mode() != DisplayServer.WINDOW_MODE_FULLSCREEN):
		screenScale = int(clamp(screenScale+val, 1, screenScaleMax))
		print("add")
	#get_viewport().set_size(Vector2(screenScale * 64,screenScale * 64))
	DisplayServer.window_set_size(Vector2(screenScale * 160,screenScale * 120))
	setScreenScaleText()
	print(screenScale)
	
func change_Music(val):
	musicVol = clamp(musicVol+val,0,10)
	updateMusic()	
	
func updateMusic():
	if(musicVol == 0):
		AudioServer.set_bus_mute(AudioServer.get_bus_index("Music"),true)
	else:
		AudioServer.set_bus_mute(AudioServer.get_bus_index("Music"),false)
	AudioServer.set_bus_volume_db(AudioServer.get_bus_index("Music"),musicVol-10)
	config_Music_Bar.value = musicVol
	
func change_SFX(val):
	SFXVol = clamp(SFXVol+val,0,10)
	updateSFX()	
	
func updateSFX():
	if(SFXVol == 0):
		AudioServer.set_bus_mute(AudioServer.get_bus_index("SFX"),true)
	else:
		AudioServer.set_bus_mute(AudioServer.get_bus_index("SFX"),false)
	AudioServer.set_bus_volume_db(AudioServer.get_bus_index("SFX"),SFXVol-10)
	config_SFX_Bar.value = SFXVol
	
func change_Voice(val):
	voiceVol = clamp(voiceVol + val,0,10)
	updateVoice()	
	
func updateVoice():
	if(voiceVol == 0):
		AudioServer.set_bus_mute(AudioServer.get_bus_index("Voice"),true)
	else:
		AudioServer.set_bus_mute(AudioServer.get_bus_index("Voice"),false)
	AudioServer.set_bus_volume_db(AudioServer.get_bus_index("Voice"),voiceVol-10)
	config_Voice_Bar.value = voiceVol
	
func setScreenScaleText():
	get_node("CanvasLayer/Config-Btns-Control/Screen-Size/Screen-Size-Font-Text").bbcode_text = "[center]"+str(screenScale)+"[/center]"

func _on_music_bar_left_arrow_button_down():
	change_Music(-1)

func _on_music_bar_right_arrow_button_down():
	change_Music(1)

func _on_sfx_bar_left_arrow_button_down():
	change_SFX(-1)

func _on_sfx_bar_right_arrow_button_down():
	change_SFX(1)

func _on_voice_bar_left_arrow_button_down():
	change_Voice(-1)

func _on_voice_bar_right_arrow_button_down():
	change_Voice(1)

func _on_screen_size_bar_left_arrow_button_down():
	updateScreenTextAndSize(-1)

func _on_screen_size_bar_right_arrow_button_down():
	updateScreenTextAndSize(1)

func _on_to_title_btn_button_down():
	TransitionManager.transitionClose(titleScenePath, false)
	changePaused(false)

func _on_back_btn_button_down():
	changePaused(false)

func _on_full_screen_btn_toggled(toggled_on):
	if(toggled_on):
		DisplayServer.window_set_mode(DisplayServer.WINDOW_MODE_FULLSCREEN)
	else:
		DisplayServer.window_set_mode(DisplayServer.WINDOW_MODE_WINDOWED)
	#AudioStreamHolder.playPressedButtonChime()	

func _on_credits_to_title_btn_button_down():
	TransitionManager.transitionClose(titleScenePath, false)
	changePaused(false)

func _on_credits_back_btn_button_down():
	
	changePaused(false)

func _on_patreon_btn_button_down():
	OS.shell_open("https://www.patreon.com/countmoxi")

func _on_sub_star_btn_button_down():
	OS.shell_open("https://subscribestar.adult/countmoxi")

func _on_twitter_btn_button_down():
	OS.shell_open("https://twitter.com/CountMoxi")

func _on_newgrounds_btn_button_down():
	OS.shell_open("https://countmoxi.newgrounds.com/")

func _on_pixiv_btn_button_down():
	OS.shell_open("https://pixiv.me/countmoxi")

func _on_itch_btn_button_down():
	OS.shell_open("https://countmoxi.itch.io/")

func _on_blogger_btn_button_down():
	OS.shell_open("https://countmoxi.blogspot.com/")

func _on_tera_twitter_btn_button_down():
	OS.shell_open("https://x.com/TeraTyrantS")
